Orders
======

This module contains all order classes as well as helper methods for working
with these.

.. autoclass:: algotradepy.orders.AnOrder
    :members:
    :undoc-members:

.. autoclass:: algotradepy.orders.MarketOrder
    :members:

.. autoclass:: algotradepy.orders.LimitOrder
    :members:
    :undoc-members:

.. autoclass:: algotradepy.orders.TrailingStopOrder
    :members:
    :undoc-members:

.. autoclass:: algotradepy.orders.OrderAction
    :members:

.. autoclass:: algotradepy.orders.TimeInForce
    :members:
